# cdk8s+ (cdk8s-plus)

### High level constructs for Kubernetes

![Stability:Beta](https://img.shields.io/badge/stability-beta-orange)

<!-- [![build](https://github.com/cdk8s-team/cdk8s-plus-17/workflows/release/badge.svg)](https://github.com/cdk8s-team/cdk8s-plus-17/actions/workflows/release.yml)
[![npm version](https://badge.fury.io/js/cdk8s-plus-17.svg)](https://badge.fury.io/js/cdk8s-plus-17)
[![PyPI version](https://badge.fury.io/py/cdk8s-plus-17.svg)](https://badge.fury.io/py/cdk8s-plus-17)
[![NuGet version](https://badge.fury.io/nu/Org.Cdk8s.Plus17.svg)](https://badge.fury.io/nu/Org.Cdk8s.Plus17)
[![Maven Central](https://maven-badges.herokuapp.com/maven-central/org.cdk8s/cdk8s-plus-17/badge.svg)](https://maven-badges.herokuapp.com/maven-central/org.cdk8s/cdk8s-plus-17) -->

**cdk8s+** is a software development framework that provides high level abstractions for authoring Kubernetes applications.
Built on top of the auto generated building blocks provided by [cdk8s](../cdk8s), this library includes a hand crafted *construct*
for each native kubernetes object, exposing richer API's with reduced complexity.

## Documentation

See [cdk8s.io](https://cdk8s.io/docs/latest/plus).

## License

This project is distributed under the [Apache License, Version 2.0](./LICENSE).

This module is part of the [cdk8s project](https://github.com/cdk8s-team).
